@@ -2,9 +2,9 @@ import threading
 
 from asgiref.sync import async_to_sync
 
-from janus.utils import run_coro_task
-from janus.plugins import Plugin
-from janus.session import WebsocketSession
+from janus_api.utils import run_coro_task
+from janus_api.plugins import Plugin
+from janus_api.session import WebsocketSession
 
 
 def get_session(sid=None):
