@@ -1,4 +1,4 @@
-from janus.plugins.base import Plugin, PluginRegistry
+from janus_api.plugins.base import Plugin, PluginRegistry
 
 def _load_plugins():
     try:
