@@ -16,8 +16,8 @@ from pydantic import TypeAdapter, ValidationError
 from reactivex import (Observable, Subject as RxSubject, operators as rx_ops, )
 from websockets import WebSocketException, ConnectionClosedError, ConnectionClosedOK
 
-from janus.models import JanusRequest, JanusResponse
-from janus.models.response import AckResponse, EventResponse, ErrorResponse, SuccessResponse, KeepAliveResponse, \
+from janus_api.models import JanusRequest, JanusResponse
+from janus_api.models.response import AckResponse, EventResponse, ErrorResponse, SuccessResponse, KeepAliveResponse, \
     WebRTCEvent, Jsep
 
 logger = logging.getLogger("janus.transport")
