@@ -1,5 +1,6 @@
 import asyncio
 import typing
+import uuid
 from functools import partial
 from typing import Coroutine
 
@@ -20,3 +21,7 @@ def from_coroutine[T](
 ) -> T:
     fn = partial(async_to_sync, coro)
     return fn(*args, **kwargs)
+
+
+def generate_id(length=6) -> str:
+    return str(uuid.uuid4())[:length]
\ No newline at end of file
